summaryrefslogtreecommitdiff
path: root/src/gui
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui')
-rw-r--r--src/gui/buysell.cpp6
-rw-r--r--src/gui/buysell.h7
-rw-r--r--src/gui/status.cpp (renamed from src/gui/stats.cpp)8
-rw-r--r--src/gui/status.h (renamed from src/gui/stats.h)8
4 files changed, 9 insertions, 20 deletions
diff --git a/src/gui/buysell.cpp b/src/gui/buysell.cpp
index 730689e0..eae19917 100644
--- a/src/gui/buysell.cpp
+++ b/src/gui/buysell.cpp
@@ -61,9 +61,3 @@ BuySellDialog::~BuySellDialog()
delete sellButton;
delete cancelButton;
}
-
-void BuySellDialog::action(const std::string& eventId)
-{
- if (eventId == "cancel") {
- }
-}
diff --git a/src/gui/buysell.h b/src/gui/buysell.h
index fb03cc9e..5289f649 100644
--- a/src/gui/buysell.h
+++ b/src/gui/buysell.h
@@ -32,7 +32,7 @@
*
* \ingroup GUI
*/
-class BuySellDialog : public Window, public gcn::ActionListener {
+class BuySellDialog : public Window {
public:
/**
* Constructor. The action listener passed will receive "sell", "buy"
@@ -47,11 +47,6 @@ class BuySellDialog : public Window, public gcn::ActionListener {
*/
~BuySellDialog();
- /**
- * Called when receiving actions from the widgets.
- */
- void action(const std::string& eventId);
-
private:
gcn::Button *buyButton;
gcn::Button *sellButton;
diff --git a/src/gui/stats.cpp b/src/gui/status.cpp
index 949c6c27..026ac9a3 100644
--- a/src/gui/stats.cpp
+++ b/src/gui/status.cpp
@@ -21,9 +21,9 @@
* $Id$
*/
-#include "stats.h"
+#include "status.h"
-StatsDialog::StatsDialog(gcn::Container *parent):
+StatusDialog::StatusDialog(gcn::Container *parent):
Window(parent, "%s Lvl: % 2i Job: % 2i")
{
hp = new gcn::Label("HP");
@@ -46,7 +46,7 @@ StatsDialog::StatsDialog(gcn::Container *parent):
add(manaBar);
}
-StatsDialog::~StatsDialog()
+StatusDialog::~StatusDialog()
{
delete hp;
delete sp;
@@ -55,7 +55,7 @@ StatsDialog::~StatsDialog()
delete manaBar;
}
-void StatsDialog::update()
+void StatusDialog::update()
{
char *tempstr = new char[64];
diff --git a/src/gui/stats.h b/src/gui/status.h
index 19971469..49a9595d 100644
--- a/src/gui/stats.h
+++ b/src/gui/status.h
@@ -35,14 +35,14 @@
#include <allegro.h>
/**
* The player statistics dialog.
*
* \ingroup GUI
*/
-class StatsDialog : public Window {
+class StatusDialog : public Window {
public:
- StatsDialog(gcn::Container *parent);
- ~StatsDialog();
+ StatusDialog(gcn::Container *parent);
+ ~StatusDialog();
/**
* Updates this dialog with values from PLAYER_INFO *char_info
@@ -35,14 +35,14 @@
#include <allegro.h>
/**
- * The player statistics dialog.
+ * The player status dialog.
*
* \ingroup GUI